"""
Input/output methods declaration.
"""
from .inputparser import ReadYaml
from .outmesh import WriteMesh
